@@ -3,14 +3,14 @@
 
 namespace Icinga\Data\Db;
 
+use DateInterval;
+use DateTime;
+use DateTimeZone;
 use Exception;
+use Icinga\Data\Filter\Filter;
 use Zend_Db_Expr;
 use Zend_Db_Select;
 use Icinga\Application\Logger;
-use Icinga\Data\Filter\FilterAnd;
-use Icinga\Data\Filter\FilterChain;
-use Icinga\Data\Filter\FilterNot;
-use Icinga\Data\Filter\FilterOr;
 use Icinga\Data\SimpleQuery;
 use Icinga\Exception\ProgrammingError;
 use Icinga\Exception\QueryException;
@@ -113,6 +113,23 @@ class DbQuery extends SimpleQuery
         return parent::where($condition, $value);
     }
 
+    public function addFilter(Filter $filter)
+    {
+        $this->expressionsToTimestamp($filter);
+        return parent::addFilter($filter);
+    }
+
+    private function expressionsToTimestamp(Filter $filter)
+    {
+        if ($filter->isChain()) {
+            foreach ($filter->filters() as $child) {
+                $this->expressionsToTimestamp($child);
+            }
+        } elseif ($this->isTimestamp($filter->getColumn())) {
+            $filter->setExpression($this->valueToTimestamp($filter->getExpression()));
+        }
+    }
+
     protected function dbSelect()
     {
         return clone $this->select;
@@ -176,55 +193,12 @@ class DbQuery extends SimpleQuery
 
     protected function applyFilterSql($select)
     {
-        $where = $this->renderFilter($this->filter);
+        $where = $this->getDatasource()->renderFilter($this->filter);
         if ($where !== '') {
             $select->where($where);
         }
     }
 
-    /**
-     * @deprecated  Use DbConnection::renderFilter() instead!
-     */
-    protected function renderFilter($filter, $level = 0)
-    {
-        $str = '';
-        if ($filter instanceof FilterChain) {
-            if ($filter instanceof FilterAnd) {
-                $op = ' AND ';
-            } elseif ($filter instanceof FilterOr) {
-                $op = ' OR ';
-            } elseif ($filter instanceof FilterNot) {
-                $op = ' AND ';
-                $str .= ' NOT ';
-            } else {
-                throw new QueryException(
-                    'Cannot render filter: %s',
-                    $filter
-                );
-            }
-            $parts = array();
-            if (! $filter->isEmpty()) {
-                foreach ($filter->filters() as $f) {
-                    $filterPart = $this->renderFilter($f, $level + 1);
-                    if ($filterPart !== '') {
-                        $parts[] = $filterPart;
-                    }
-                }
-                if (! empty($parts)) {
-                    if ($level > 0) {
-                        $str .= ' (' . implode($op, $parts) . ') ';
-                    } else {
-                        $str .= implode($op, $parts);
-                    }
-                }
-            }
-        } else {
-            $str .= $this->whereToSql($filter->getColumn(), $filter->getSign(), $filter->getExpression());
-        }
-
-        return $str;
-    }
-
     protected function escapeForSql($value)
     {
         // bindParam? bindValue?
@@ -250,27 +224,51 @@ class DbQuery extends SimpleQuery
 
     protected function valueToTimestamp($value)
     {
-        // We consider integers as valid timestamps. Does not work for URL params
-        if (! is_string($value) || ctype_digit($value)) {
-            return $value;
+        if (is_string($value)) {
+            if (ctype_digit($value)) {
+                $value = (int) $value;
+            } else {
+                $value = strtotime($value);
+            }
+        } elseif (! is_int($value)) {
+            $value = (int) $value;
         }
-        $value = strtotime($value);
-        if (! $value) {
-            /*
-            NOTE: It's too late to throw exceptions, we might finish in __toString
-            throw new QueryException(sprintf(
-                '"%s" is not a valid time expression',
-                $value
-            ));
-            */
-        }
-        return $value;
+
+        return $this->timestampForSql($value);
     }
 
+    /**
+     * Render the given timestamp based on the local timezone
+     *
+     * Since {@see DbConnection::defaultTimezoneOffset()} tells the database the timezone with just an offset,
+     * this will prepare the rendered value in a way that it plays fine with daylight savings.
+     *
+     * @param int $value
+     * @return string
+     */
     protected function timestampForSql($value)
     {
-        // TODO: do this db-aware
-        return $this->escapeForSql(date('Y-m-d H:i:s', $value));
+        if ($this->getDatasource()->getDbType() === 'pgsql') {
+            // We don't tell PostgreSQL the user's timezone
+            $dateTime = (new DateTime())
+                ->setTimezone(new DateTimeZone('UTC'))
+                ->setTimestamp($value);
+        } else {
+            $dateTime = new DateTime();
+            // Get "current" offset the database will use
+            $offsetToUTC = $dateTime->getOffset();
+            // Set timezone to UTC and initialize it with the timestamp
+            $dateTime->setTimezone(new DateTimeZone('UTC'))->setTimestamp($value);
+            // Normalize every datetime based on the only offset the database knows about
+            if ($offsetToUTC >= 0) {
+                $dateTime->add(new DateInterval("PT{$offsetToUTC}S"));
+            } else {
+                $offsetToUTC = abs($offsetToUTC);
+                $dateTime->sub(new DateInterval("PT{$offsetToUTC}S"));
+            }
+        }
+
+        return $dateTime->format('Y-m-d H:i:s');
     }
 
     /**
@@ -291,63 +289,6 @@ class DbQuery extends SimpleQuery
         return false;
     }
 
-    public function whereToSql($col, $sign, $expression)
-    {
-        if ($this->isTimestamp($col)) {
-            $expression = $this->valueToTimestamp($expression);
-        }
-
-        if (is_array($expression)) {
-            $comp = [];
-            $pattern = [];
-            foreach ($expression as $value) {
-                if (strpos($value, '*') === false) {
-                    $comp[] = $value;
-                } else {
-                    $pattern[] = $this->whereToSql($col, $sign, $value);
-                }
-            }
-            $sql = $pattern;
-            if ($sign === '=') {
-                if (! empty($comp)) {
-                    $sql[] = $col . ' IN (' . $this->escapeForSql($comp) . ')';
-                }
-                $operator = 'OR';
-            } elseif ($sign === '!=') {
-                if (! empty($comp)) {
-                    $sql[] = sprintf('(%1$s NOT IN (%2$s) OR %1$s IS NULL)', $col, $this->escapeForSql($comp));
-                }
-                $operator = 'AND';
-            } else {
-                throw new QueryException(
-                    'Unable to render array expressions with operators other than equal or not equal'
-                );
-            }
-
-            return '(' . implode(" $operator ", $sql) . ')';
-        } elseif ($sign === '=' && strpos($expression, '*') !== false) {
-            if ($expression === '*') {
-                return $col . ' IS NOT NULL';
-            }
-
-            return $col . ' LIKE ' . $this->escapeForSql($this->escapeWildcards($expression));
-        } elseif ($sign === '!=' && strpos($expression, '*') !== false) {
-            if ($expression === '*') {
-                return $col . ' IS NULL';
-            }
-
-            return sprintf(
-                '(%1$s NOT LIKE %2$s OR %1$s IS NULL)',
-                $col,
-                $this->escapeForSql($this->escapeWildcards($expression))
-            );
-        } elseif ($sign === '!=') {
-            return sprintf('(%1$s %2$s %3$s OR %1$s IS NULL)', $col, $sign, $this->escapeForSql($expression));
-        } else {
-            return sprintf('%s %s %s', $col, $sign, $this->escapeForSql($expression));
-        }
-    }
-
     /**
      * Get the count query
      *
@@ -379,7 +320,7 @@ class DbQuery extends SimpleQuery
      *
      * @return int
      */
-    public function count()
+    public function count(): int
     {
         if ($this->count === null) {
             $this->count = parent::count();
