@@ -23,18 +23,24 @@ class HostcommenthistoryQuery extends IdoQuery
      */
     protected $groupOrigin = array('hostgroups', 'services');
 
+    protected $subQueryTargets = array(
+        'hostgroups'    => 'hostgroup',
+        'servicegroups' => 'servicegroup'
+    );
+
     /**
      * {@inheritdoc}
      */
     protected $columnMap = array(
         'commenthistory' => array(
+            'id'            => 'hch.commenthistory_id',
             'host'          => 'ho.name1 COLLATE latin1_general_ci',
             'host_name'     => 'ho.name1',
             'object_id'     => 'hch.object_id',
             'object_type'   => '(\'host\')',
             'output'        => "('[' || hch.author_name || '] ' || hch.comment_data)",
             'state'         => '(-1)',
-            'timestamp'     => 'UNIX_TIMESTAMP(hch.comment_time)',
+            'timestamp'     => 'hch.comment_time',
             'type'          => "(CASE hch.entry_type WHEN 1 THEN 'comment' WHEN 2 THEN 'dt_comment' WHEN 3 THEN 'flapping' WHEN 4 THEN 'ack' END)"
         ),
         'hostgroups' => array(
@@ -62,16 +68,13 @@ class HostcommenthistoryQuery extends IdoQuery
         )
     );
 
-    /**
-     * {@inheritdoc}
-     */
-    public function whereToSql($col, $sign, $expression)
+    public function isTimestamp($field)
     {
-        if ($col === 'UNIX_TIMESTAMP(hch.comment_time)') {
-            return 'hch.comment_time ' . $sign . ' ' . $this->timestampForSql($this->valueToTimestamp($expression));
-        } else {
-            return parent::whereToSql($col, $sign, $expression);
+        if (! parent::isTimestamp($field)) {
+            return $field === 'hch.comment_time';
         }
+
+        return true;
     }
 
     /**
@@ -170,4 +173,19 @@ class HostcommenthistoryQuery extends IdoQuery
             array()
         );
     }
+
+    protected function joinSubQuery(IdoQuery $query, $name, $filter, $and, $negate, &$additionalFilter)
+    {
+        if ($name === 'hostgroup') {
+            $query->joinVirtualTable('members');
+
+            return ['hgm.host_object_id', 'ho.object_id'];
+        } elseif ($name === 'servicegroup') {
+            $query->joinVirtualTable('services');
+
+            return ['s.host_object_id', 'ho.object_id'];
+        }
+
+        return parent::joinSubQuery($query, $name, $filter, $and, $negate, $additionalFilter);
+    }
 }
