@@ -33,6 +33,11 @@ class HoststatehistoryQuery extends IdoQuery
         'hard_state' => 1
     );
 
+    protected $subQueryTargets = array(
+        'hostgroups'    => 'hostgroup',
+        'servicegroups' => 'servicegroup'
+    );
+
     /**
      * {@inheritdoc}
      */
@@ -61,33 +66,25 @@ class HoststatehistoryQuery extends IdoQuery
             'service_host_name'     => 'so.name1'
         ),
         'statehistory' => array(
+            'id'            => 'hh.statehistory_id',
             'host'          => 'ho.name1 COLLATE latin1_general_ci',
             'host_name'     => 'ho.name1',
             'object_id'     => 'hh.object_id',
             'object_type'   => '(\'host\')',
-            'output'        => "('[ ' || hh.current_check_attempt || '/' || hh.max_check_attempts || ' ] ' || hh.output)",
+            'output'        => '(CASE WHEN hh.state_type = 1 THEN hh.output ELSE \'[ \' || hh.current_check_attempt || \'/\' || hh.max_check_attempts || \' ] \' || hh.output END)',
             'state'         => 'hh.state',
-            'timestamp'     => 'UNIX_TIMESTAMP(hh.state_time)',
+            'timestamp'     => 'hh.state_time',
             'type'          => "(CASE WHEN hh.state_type = 1 THEN 'hard_state' ELSE 'soft_state' END)"
         ),
     );
 
-    /**
-     * {@inheritdoc}
-     */
-    public function whereToSql($col, $sign, $expression)
+    public function isTimestamp($field)
     {
-        if ($col === 'UNIX_TIMESTAMP(hh.state_time)') {
-            return 'hh.state_time ' . $sign . ' ' . $this->timestampForSql($this->valueToTimestamp($expression));
-        } elseif (
-            $col === $this->columnMap['statehistory']['type']
-            && ! is_array($expression)
-            && array_key_exists($expression, $this->types)
-        ) {
-            return 'hh.state_type ' . $sign . ' ' . $this->types[$expression];
-        } else {
-            return parent::whereToSql($col, $sign, $expression);
+        if (! parent::isTimestamp($field)) {
+            return $field === 'hh.state_time';
         }
+
+        return true;
     }
 
     /**
@@ -186,4 +183,19 @@ class HoststatehistoryQuery extends IdoQuery
             array()
         );
     }
+
+    protected function joinSubQuery(IdoQuery $query, $name, $filter, $and, $negate, &$additionalFilter)
+    {
+        if ($name === 'hostgroup') {
+            $query->joinVirtualTable('members');
+
+            return ['hgm.host_object_id', 'ho.object_id'];
+        } elseif ($name === 'servicegroup') {
+            $query->joinVirtualTable('services');
+
+            return ['s.host_object_id', 'ho.object_id'];
+        }
+
+        return parent::joinSubQuery($query, $name, $filter, $and, $negate, $additionalFilter);
+    }
 }
