@@ -616,16 +616,18 @@ abstract class IdoQuery extends DbQuery
             }
         }
 
-        if ($and || $negate && ! $and) {
+        if ($and || $negate) {
             // Having is only required for AND and != filters,
             // e.g. hostgroup_name=(ping&linux), hostgroup_name!=ping, hostgroup_name!=(ping|linux)
             $groups = $subQuery->getGroup();
-            $group = $groups[0];
-            $group = preg_replace('/(?<=^|\s)\w+(?=\.)/', 'sub_$0', $group);
+            if (! empty($groups)) {
+                $group = $groups[0];
+                $group = preg_replace('/(?<=^|\s)\w+(?=\.)/', 'sub_$0', $group);
 
-            $cnt = count($expr);
+                $cnt = count($expr);
 
-            $subQuery->select()->having("COUNT(DISTINCT $group) >= $cnt");
+                $subQuery->select()->having("COUNT(DISTINCT $group) >= $cnt");
+            }
         }
 
         $subQueryFilter->setColumn(preg_replace(
@@ -781,6 +783,30 @@ abstract class IdoQuery extends DbQuery
         return parent::where($col, $value);
     }
 
+    /**
+     * Add a filter expression, with as less validation as possible
+     *
+     * @param FilterExpression $ex
+     *
+     * @internal If you use this outside the monitoring module, it's your fault if something breaks
+     * @return $this
+     */
+    public function whereEx(FilterExpression $ex)
+    {
+        $this->requireColumn($ex->getColumn());
+        $col = $this->getMappedField($ex->getColumn());
+        if ($col === null) {
+            throw new IcingaException(
+                'No such field: %s',
+                $ex->getColumn()
+            );
+        }
+
+        parent::addFilter((clone $ex)->setColumn($col));
+
+        return $this;
+    }
+
     /**
      * Return true if an field contains an explicit timestamp
      *
@@ -872,6 +898,10 @@ abstract class IdoQuery extends DbQuery
             '%1$s = %2$s.object_id AND LOWER(%2$s.varname) = %3$s';
         foreach ($this->columnMap as $table => & $columns) {
             foreach ($columns as $alias => & $column) {
+                if ($column === null) {
+                    continue;
+                }
+
                 // Using a regex here because COLLATE may occur anywhere in the string
                 $column = preg_replace('/ COLLATE .+$/', '', $column, -1, $count);
                 if ($count > 0) {
@@ -1192,9 +1222,7 @@ abstract class IdoQuery extends DbQuery
         $this->customVars[strtolower($customvar)] = $alias;
 
         if ($type === 'host') {
-            if (
-                $this instanceof HostserviceproblemsummaryQuery
-                || $this instanceof ServicecommentQuery
+            if ($this instanceof ServicecommentQuery
                 || $this instanceof ServicedowntimeQuery
                 || $this instanceof ServicecommenthistoryQuery
                 || $this instanceof ServicedowntimestarthistoryQuery
