@@ -33,6 +33,11 @@ class ServicestatehistoryQuery extends IdoQuery
         'hard_state' => 1
     );
 
+    protected $subQueryTargets = array(
+        'hostgroups'    => 'hostgroup',
+        'servicegroups' => 'servicegroup'
+    );
+
     /**
      * {@inheritdoc}
      */
@@ -58,37 +63,29 @@ class ServicestatehistoryQuery extends IdoQuery
             'service_display_name'  => 's.display_name COLLATE latin1_general_ci'
         ),
         'statehistory' => array(
+            'id'                    => 'sh.statehistory_id',
             'host'                  => 'so.name1 COLLATE latin1_general_ci',
             'host_name'             => 'so.name1',
             'object_id'             => 'sh.object_id',
             'object_type'           => '(\'service\')',
-            'output'                => "('[ ' || sh.current_check_attempt || '/' || sh.max_check_attempts || ' ] ' || sh.output)",
+            'output'                => '(CASE WHEN sh.state_type = 1 THEN sh.output ELSE \'[ \' || sh.current_check_attempt || \'/\' || sh.max_check_attempts || \' ] \' || sh.output END)',
             'service'               => 'so.name2 COLLATE latin1_general_ci',
             'service_description'   => 'so.name2',
             'service_host'          => 'so.name1 COLLATE latin1_general_ci',
             'service_host_name'     => 'so.name1',
             'state'                 => 'sh.state',
-            'timestamp'             => 'UNIX_TIMESTAMP(sh.state_time)',
+            'timestamp'             => 'sh.state_time',
             'type'                  => "(CASE WHEN sh.state_type = 1 THEN 'hard_state' ELSE 'soft_state' END)"
         ),
     );
 
-    /**
-     * {@inheritdoc}
-     */
-    public function whereToSql($col, $sign, $expression)
+    public function isTimestamp($field)
     {
-        if ($col === 'UNIX_TIMESTAMP(sh.state_time)') {
-            return 'sh.state_time ' . $sign . ' ' . $this->timestampForSql($this->valueToTimestamp($expression));
-        } elseif (
-            $col === $this->columnMap['statehistory']['type']
-            && ! is_array($expression)
-            && array_key_exists($expression, $this->types)
-        ) {
-            return 'sh.state_type ' . $sign . ' ' . $this->types[$expression];
-        } else {
-            return parent::whereToSql($col, $sign, $expression);
+        if (! parent::isTimestamp($field)) {
+            return $field === 'sh.state_time';
         }
+
+        return true;
     }
 
     /**
@@ -184,4 +181,19 @@ class ServicestatehistoryQuery extends IdoQuery
             array()
         );
     }
+
+    protected function joinSubQuery(IdoQuery $query, $name, $filter, $and, $negate, &$additionalFilter)
+    {
+        if ($name === 'hostgroup') {
+            $query->joinVirtualTable('services');
+
+            return ['so.object_id', 'so.object_id'];
+        } elseif ($name === 'servicegroup') {
+            $query->joinVirtualTable('members');
+
+            return ['sgm.service_object_id', 'so.object_id'];
+        }
+
+        return parent::joinSubQuery($query, $name, $filter, $and, $negate, $additionalFilter);
+    }
 }
